# Set up options needed for ConfigureWrapping
# Useful Variables:
# The user should set JAVA_OUTPUT_DIR if they want generated Java classes to go
# anywhere other than ${PROJECT_BINARY_DIR}/Java.
# If SWIG needs to include any files in nonstandard locations, the directories
# must be added to with include_directories().

# Be careful setting up the paths to the ITK and gccxml dirs that WrapITK
# already found -- they might not be valid.
set(possible_itk_dir "/tmp/osgeo-insighttoolkit-20190315-70348-1j3cos5/InsightToolkit-4.13.1/itk-build")
if(EXISTS "${possible_itk_dir}")
set(ITK_DIR "${possible_itk_dir}" CACHE PATH "Path to ITK build or install.")
endif()

set(possible_gccxml "")
if(EXISTS "${possible_gccxml}")
set(GCCXML "${possible_gccxml}"  CACHE FILEPATH "Path to gccxml.")
endif()

set(possible_swig_dir "/usr/local/Cellar/swig/3.0.12/share/swig/3.0.12")
if(EXISTS "${possible_swig_dir}")
set(SWIG_DIR "${possible_swig_dir}"  CACHE PATH "Path to Swig build or install")
endif()

# Set up the rest of the variables that WrapITK was built with.
set(ITK_WRAP_unsigned_char ON CACHE BOOL "Wrap unsigned char type")
set(ITK_WRAP_unsigned_short OFF CACHE BOOL "Wrap unsigned short type")
set(ITK_WRAP_unsigned_long OFF CACHE BOOL "Wrap unsigned long type")
set(ITK_WRAP_unsigned_long_long OFF CACHE BOOL "Wrap unsigned long long type")
set(ITK_WRAP_signed_char OFF CACHE BOOL "Wrap signed char type")
set(ITK_WRAP_signed_short ON CACHE BOOL "Wrap signed short type")
set(ITK_WRAP_signed_long OFF CACHE BOOL "Wrap signed long type")
set(ITK_WRAP_signed_long_long OFF CACHE BOOL "Wrap signed long long type")
set(ITK_WRAP_float ON CACHE BOOL "Wrap float type")
set(ITK_WRAP_double OFF CACHE BOOL "Wrap double type")
set(ITK_WRAP_vector_float ON CACHE BOOL "Wrap vector float type")
set(ITK_WRAP_vector_double OFF CACHE BOOL "Wrap vector double type")
set(ITK_WRAP_covariant_vector_float ON CACHE BOOL "Wrap covariant vector float type")
set(ITK_WRAP_covariant_vector_double OFF CACHE BOOL "Wrap covariant vector double type")
set(ITK_WRAP_rgb_unsigned_char ON CACHE BOOL "Wrap RGB< unsigned char > type")
set(ITK_WRAP_rgb_unsigned_short OFF CACHE BOOL "Wrap RGB< unsigned short > type")
set(ITK_WRAP_complex_float ON CACHE BOOL "Wrap complex<float> type")
set(ITK_WRAP_complex_double OFF CACHE BOOL "Wrap complex<double> type")
set(ITK_WRAP_IMAGE_DIMS "2;3" CACHE STRING "dimensions available separated by semicolons (;)")



foreach(var ITK_DIR GCCXML
    ITK_WRAP_unsigned_char ITK_WRAP_unsigned_short ITK_WRAP_unsigned_long ITK_WRAP_signed_char
    ITK_WRAP_signed_short ITK_WRAP_signed_long ITK_WRAP_float ITK_WRAP_double ITK_WRAP_vector_float
    ITK_WRAP_vector_double ITK_WRAP_covariant_vector_float ITK_WRAP_covariant_vector_double
    ITK_WRAP_rgb_unsigned_char ITK_WRAP_rgb_unsigned_short ITK_WRAP_complex_float ITK_WRAP_complex_double
    ITK_WRAP_rgba_unsigned_char ITK_WRAP_rgba_unsigned_short
    ITK_WRAP_IMAGE_DIMS)
  mark_as_advanced(${var})
endforeach()

set(WRAP_ITK_CONFIG_DIR "${WrapITK_DIR}/Configuration/Inputs")
set(WRAP_ITK_CMAKE_DIR "${WrapITK_DIR}/Configuration")
if("${WrapITK_DIR}" MATCHES "^${CMAKE_INSTALL_PREFIX}")
  string(REGEX REPLACE "^${CMAKE_INSTALL_PREFIX}/*" "" prefix "${WrapITK_DIR}")
  set(WRAP_ITK_INSTALL_PREFIX "${prefix}" CACHE PATH "subpath where where most of WrapITK files will be installed")
else()
  message("Warning: the CMAKE_INSTALL_PREFIX doesn't match the WrapITK one. Your installation may not be usable.")
  set(WRAP_ITK_INSTALL_PREFIX "lib/cmake/ITK-4.13/WrapITK/" CACHE PATH "subpath where where most of WrapITK files will be installed")
endif()

if(JAVA_OUTPUT_DIR)
  set(ITK_WRAP_JAVA_DIR "${JAVA_OUTPUT_DIR}")
else()
  set(ITK_WRAP_JAVA_DIR "${PROJECT_BINARY_DIR}/Java")
  if(${module_prefix}_WRAP_JAVA)
    file(MAKE_DIRECTORY "${ITK_WRAP_JAVA_DIR}")
  endif()
endif()

set(WRAP_ITK_INSTALL_LOCATION "${WrapITK_DIR}")
set(WRAP_ITK_TYPEDEFS_DIRECTORY "${WrapITK_DIR}/Configuration/Typedefs")
set(WRAP_ITK_LIB_DIRECTORY "${WrapITK_DIR}/lib")
set(WRAP_ITK_MODULES "ITKCommon;BridgeNumPy;ITKFiniteDifference;ITKImageFilterBase;ITKCurvatureFlow;ITKStatistics;ITKTransform;ITKImageFunction;ITKImageGrid;ITKAnisotropicSmoothing;ITKLabelMap;ITKImageCompose;ITKMesh;ITKSpatialObjects;ITKImageStatistics;ITKPath;ITKImageIntensity;ITKThresholding;ITKConnectedComponents;ITKMathematicalMorphology;ITKBinaryMathematicalMorphology;ITKImageLabel;ITKNarrowBand;ITKDistanceMap;ITKQuadEdgeMesh;ITKFastMarching;ITKIOImageBase;ITKImageCompare;ITKSmoothing;ITKImageGradient;ITKImageSources;ITKImageFeature;ITKOptimizers;ITKLevelSets;ITKAntiAlias;ITKBiasCorrection;ITKClassifiers;ITKColormap;ITKFFT;ITKConvolution;ITKDeconvolution;ITKDisplacementField;ITKEigen;ITKIOSpatialObjects;ITKRegistrationCommon;ITKPDEDeformableRegistration;ITKIOBMP;ITKIOBioRad;ITKIOBruker;ITKIOGDCM;ITKIOIPL;ITKIOGE;ITKIOGIPL;ITKIOHDF5;ITKIOJPEG;ITKIOTIFF;ITKIOLSM;ITKIOMINC;ITKIOMRC;ITKIOMesh;ITKIOMeta;ITKIONIFTI;ITKIONRRD;ITKIOPNG;ITKIORAW;ITKIOSiemens;ITKIOStimulate;ITKIOTransformBase;ITKIOVTK;ITKImageFusion;ITKImageNoise;ITKLabelVoting;ITKVTK;ITKVtkGlue;ITKOptimizersv4;ITKMetricsv4;ITKQuadEdgeMeshFiltering;ITKRegionGrowing;ITKRegistrationMethodsv4;ITKVoronoi;ITKWatersheds;ITKReview;ITKTestKernel;SCIFIO")

# Tell the world that this is an external project using WrapITK:
set(EXTERNAL_WRAP_ITK_PROJECT ON)

# libraries are all in the same dir
set (CMAKE_LIBRARY_OUTPUT_DIRECTORY "${PROJECT_BINARY_DIR}/lib" CACHE INTERNAL "Single output directory for building all libraries.")

# Now include ConfigureWrapping
include("${WRAP_ITK_CMAKE_DIR}/ConfigureWrapping.cmake")

# include must be there to add the path *after* the local path
include_directories("${WrapITK_DIR}/Configuration/Typedefs")

# If WrapITK has been installed, we need to point the linker at the various
# language directories, where libSwigRuntime has been installed.
# Otherwise, we need to point the linker at the bin directory of the build dir.
macro(LINK_IF_EXISTS dir)
  if(EXISTS "${dir}")
    link_directories("${dir}")
  endif()
endmacro()

link_directories("${WrapITK_DIR}/lib")

find_program(ITK_TEST_DRIVER itkTestDriver)
